@@ -1,10 +1,24 @@
 from ckan.lib.base import *
-from ckan.controllers.base import CkanBaseController
 from simplejson import dumps
 
-class TagController(CkanBaseController):
+class TagController(BaseController):
 
     def index(self):
+        from ckan.lib.helpers import Page
+        
+        c.q = request.params.get('q', '')
+        
+        if c.q:
+            query = model.Tag.search_by_name(c.q)
+        else:
+            query = model.Session.query(model.Tag)
+           
+        c.page = Page(
+            collection=query,
+            page=request.params.get('page', 1),
+            items_per_page=100
+        )
+           
         return render('tag/index')
 
     def read(self, id):
@@ -13,16 +27,6 @@ class TagController(CkanBaseController):
             abort(404)
         return render('tag/read')
 
-    def list(self, id):
-        return self._paginate_list('tag', id, 'tag/list')
-
-    def search(self):
-        c.search_terms = request.params.get('search_terms', '')
-        if c.search_terms:
-            c.tags = list(model.Tag.search_by_name(c.search_terms))
-            c.tag_count = len(c.tags)
-        return render('tag/search')
-
     def autocomplete(self):
         incomplete = request.params.get('incomplete', '')
         if incomplete:
